"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.preprocessor = exports.transform = void 0;
const stream_1 = require("stream");
const browserify_preprocessor_1 = __importDefault(require("@cypress/browserify-preprocessor"));
const debug_1 = __importDefault(require("./debug"));
const template_1 = require("./template");
function transform(filepath) {
    if (!filepath.match(".feature$")) {
        return new stream_1.PassThrough();
    }
    debug_1.default(`compiling ${filepath}`);
    let buffer = Buffer.alloc(0);
    return new stream_1.Transform({
        transform(chunk, encoding, done) {
            buffer = Buffer.concat([buffer, chunk]);
            done();
        },
        async flush(done) {
            try {
                done(null, await template_1.compile(buffer.toString("utf8"), filepath));
                debug_1.default(`compiled ${filepath}`);
            }
            catch (e) {
                done(e);
            }
        },
    });
}
exports.transform = transform;
function preprendTransformerToOptions(options) {
    let wrappedTransform;
    if (!options.browserifyOptions ||
        !Array.isArray(options.browserifyOptions.transform)) {
        wrappedTransform = [transform];
    }
    else if (!options.browserifyOptions.transform.includes(transform)) {
        wrappedTransform = [transform, ...options.browserifyOptions.transform];
    }
    else {
        wrappedTransform = options.browserifyOptions.transform;
    }
    return Object.assign(Object.assign({}, options), { browserifyOptions: Object.assign(Object.assign({}, (options.browserifyOptions || {})), { transform: wrappedTransform }) });
}
function preprocessor(options = browserify_preprocessor_1.default.defaultOptions) {
    options = preprendTransformerToOptions(options);
    return function (file) {
        return browserify_preprocessor_1.default(options)(file);
    };
}
exports.preprocessor = preprocessor;
