"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.compile = void 0;
const gherkin_1 = require("@cucumber/gherkin");
const messages_1 = require("@cucumber/messages");
const assertions_1 = require("./assertions");
const step_definitions_1 = require("./step-definitions");
function notNull(value) {
    return value != null;
}
async function compile(data, uri) {
    const options = {
        includeSource: false,
        includeGherkinDocument: true,
        includePickles: true,
        newId: messages_1.IdGenerator.uuid(),
    };
    const envelopes = gherkin_1.generateMessages(data, uri, options);
    if (envelopes[0].parseError) {
        throw new Error(assertions_1.assertAndReturn(envelopes[0].parseError.message, "Expected parse error to have a description"));
    }
    const gherkinDocument = assertions_1.assertAndReturn(envelopes.map((envelope) => envelope.gherkinDocument).find(notNull), "Expected to find a gherkin document amongst the envelopes.");
    const pickles = envelopes.map((envelope) => envelope.pickle).filter(notNull);
    const stepDefinitions = await step_definitions_1.getStepDefinitionPaths(uri);
    return `
    const createTests = require("@badeball/cypress-cucumber-preprocessor/lib/create-tests");

    ${stepDefinitions
        .map((stepDefintion) => `require("${stepDefintion}");`)
        .join("\n    ")}

    createTests.default(
      ${JSON.stringify(gherkinDocument)},
      ${JSON.stringify(pickles)}
    );
  `;
}
exports.compile = compile;
